function dstatevar = doublependulumodefile(t,statevar,param)
%DOUBLEPENDULUMODEFILE This is the ODE file for a double pendulum with
%massless links, and point-masses at the end of each link (see text book for 
% the equations).

m1 = param.m1; m2 = param.m2; 
L1 = param.L1; L2 = param.L2; g = param.g;
theta1 = statevar(1); dtheta1 = statevar(2); 
theta2 = statevar(3); dtheta2 = statevar(4);

E = zeros(2,1);
E(1) = -L2*m2*L1*sin(theta2)*dtheta1^2-L2*g*m2*cos(theta1+theta2);
E(2) = L1*L2*m2*sin(theta2)*dtheta2^2 + ...
    2*L1*L2*dtheta1*m2*sin(theta2)*dtheta2-L2*g*m2*cos(theta1+theta2)...
    -L1*g*m1*cos(theta1)-L1*g*m2*cos(theta1);

M = zeros(2,2);
M(1,1) = m2*L2^2 + m2*L1*cos(theta2)*L2; 
M(1,2) = L2^2*m2;
M(2,1) = L1^2*m1 + L1^2*m2 + L2^2*m2 + 2*L1*L2*m2*cos(theta2);
M(2,2) = m2*L2^2 + L1*m2*cos(theta2)*L2;
C = M\E; % or equivalently 

ddtheta1 = C(1);
ddtheta2 = C(2);

dstatevar = [dtheta1; ddtheta1; dtheta2; ddtheta2];

end